@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12418 2020-07-23 07:38:18Z Casey $
+# $Id: models.py 12420 2020-07-23 08:06:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,14 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $
-# $Date: 2020-07-23 15:38:18 +0800 (Thu, 23 Jul 2020) $
-# $Revision: 12418 $
+# $Author: Lavender $
+# $Date: 2020-07-23 17:06:48 +0900 (週四, 23 七月 2020) $
+# $Revision: 12420 $
 
 from functools import wraps
 from django import forms
 from django.db import models
 from django.conf import settings
+from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
 from cms.models import CMSPlugin
 from djangocms_forms.models import FormDefinition
