@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: ThankRedirect.py 11388 2019-03-20 08:36:54Z Lavender $
+# $Id: ThankRedirect.py 12418 2020-07-23 07:38:18Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-03-20 16:36:54 +0800 (週三, 20 三月 2019) $
-# $Revision: 11388 $
+# $Author: Casey $
+# $Date: 2020-07-23 16:38:18 +0900 (週四, 23 七月 2020) $
+# $Revision: 12418 $
 
 from django import VERSION
 from django import template
@@ -44,7 +44,7 @@ def ThankRedirect(request):
         )
     else:
         errorHtml = errorHtml.render(
-                Context({'errorCode': errorCode,})
+                {'errorCode': errorCode,}
         )
     
     return mark_safe(
